@@ -1,25 +1,36 @@
 package Sah::Schema::date::dow_nums::en_or_id;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-03-08'; # DATE
+our $DATE = '2021-08-04'; # DATE
 our $DIST = 'Sah-Schemas-Date-ID'; # DIST
-our $VERSION = '0.005'; # VERSION
+our $VERSION = '0.006'; # VERSION
 
 our $schema = ['array' => {
     summary => 'Array of day-of-week numbers (1-7, 1=Monday)',
-    of => ['date::dow_num::en_or_id', {}, {}],
+    of => ['date::dow_num::en_or_id', {}],
     'x.perl.coerce_rules' => ['From_str::comma_sep'],
     'x.completion' => ['date_dow_nums_en_or_id'],
+    description => <<'_',
+
+See also <pm:Sah::Schema::date::dow_num> which is the schema for the elements.
+
+See also related schemas that coerce from other locales, e.g.
+<pm:Sah::Schema::date::dow_nums::id> (Indonesian),
+<pm:Sah::Schema::date::dow_num::en_or_id> (English/Indonesian), etc.
+
+_
     examples => [
         {value=>'', valid=>1, validated_value=>[]},
-        {value=>0, valid=>0},
+        {value=>0, valid=>0, summary=>'Has number not in 1-7'},
         {value=>1, valid=>1, validated_value=>[1]},
         {value=>"1,7", valid=>1, validated_value=>[1,7]},
         {value=>[1,7], valid=>1},
-        {value=>"1,7,8", valid=>0},
-        {value=>[1,7,8], valid=>0},
+        {value=>["Mon","MINGGu"], valid=>1, validated_value=>[1,7]},
+        {value=>'Mo,mg', valid=>1, validated_value=>[1,7]},
+        {value=>"1,7,8", valid=>0, summary=>'Has number not in 1-7'},
+        {value=>[1,7,8], valid=>0, summary=>'Has number not in 1-7'},
     ],
-}, {}];
+}];
 
 1;
 
@@ -37,23 +48,38 @@ Sah::Schema::date::dow_nums::en_or_id - Array of day-of-week numbers (1-7, 1=Mon
 
 =head1 VERSION
 
-This document describes version 0.005 of Sah::Schema::date::dow_nums::en_or_id (from Perl distribution Sah-Schemas-Date-ID), released on 2020-03-08.
+This document describes version 0.006 of Sah::Schema::date::dow_nums::en_or_id (from Perl distribution Sah-Schemas-Date-ID), released on 2021-08-04.
 
 =head1 SYNOPSIS
 
-Using with L<Data::Sah>:
+To check data against this schema (requires L<Data::Sah>):
 
  use Data::Sah qw(gen_validator);
- my $vdr = gen_validator("date::dow_nums::en_or_id*");
- say $vdr->($data) ? "valid" : "INVALID!";
+ my $validator = gen_validator("date::dow_nums::en_or_id*");
+ say $validator->($data) ? "valid" : "INVALID!";
 
- # Data::Sah can also create a validator to return error message, coerced value,
- # even validators in other languages like JavaScript, from the same schema.
- # See its documentation for more details.
+ # Data::Sah can also create validator that returns nice error message string
+ # and/or coerced value. Data::Sah can even create validator that targets other
+ # language, like JavaScript. All from the same schema. See its documentation
+ # for more details.
 
-Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
+To validate function parameters against this schema (requires L<Params::Sah>):
 
- package MyApp;
+ use Params::Sah qw(gen_validator);
+
+ sub myfunc {
+     my @args = @_;
+     state $validator = gen_validator("date::dow_nums::en_or_id*");
+     $validator->(\@args);
+     ...
+ }
+
+To specify schema in L<Rinci> function metadata and use the metadata with
+L<Perinci::CmdLine> to create a CLI:
+
+ # in lib/MyApp.pm
+ package
+   MyApp;
  our %SPEC;
  $SPEC{myfunc} = {
      v => 1.1,
@@ -70,12 +96,28 @@ Using in L<Rinci> function metadata (to be used with L<Perinci::CmdLine>, etc):
      my %args = @_;
      ...
  }
+ 1;
+
+ # in myapp.pl
+ package
+   main;
+ use Perinci::CmdLine::Any;
+ Perinci::CmdLine::Any->new(url=>'/MyApp/myfunc')->run;
+
+ # in command-line
+ % ./myapp.pl --help
+ myapp - Routine to do blah ...
+ ...
+
+ % ./myapp.pl --version
+
+ % ./myapp.pl --arg1 ...
 
 Sample data:
 
  ""  # valid, becomes []
 
- 0  # INVALID
+ 0  # INVALID (Has number not in 1-7)
 
  1  # valid, becomes [1]
 
@@ -83,9 +125,13 @@ Sample data:
 
  [1,7]  # valid
 
- "1,7,8"  # INVALID
+ ["Mon","MINGGu"]  # valid, becomes [1,7]
 
- [1,7,8]  # INVALID
+ "Mo,mg"  # valid, becomes [1,7]
+
+ "1,7,8"  # INVALID (Has number not in 1-7)
+
+ [1,7,8]  # INVALID (Has number not in 1-7)
 
 =head1 DESCRIPTION
 
@@ -123,7 +169,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2020, 2019 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020, 2019 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
